# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from grafeas.grafeas_v1.types import common, intoto_statement

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "SBOMReferenceNote",
        "SBOMReferenceOccurrence",
        "SbomReferenceIntotoPayload",
        "SbomReferenceIntotoPredicate",
    },
)


class SBOMReferenceNote(proto.Message):
    r"""The note representing an SBOM reference.

    Attributes:
        format_ (str):
            The format that SBOM takes. E.g. may be spdx,
            cyclonedx, etc...
        version (str):
            The version of the format that the SBOM
            takes. E.g. if the format is spdx, the version
            may be 2.3.
    """

    format_: str = proto.Field(
        proto.STRING,
        number=1,
    )
    version: str = proto.Field(
        proto.STRING,
        number=2,
    )


class SBOMReferenceOccurrence(proto.Message):
    r"""The occurrence representing an SBOM reference as applied to a
    specific resource. The occurrence follows the DSSE
    specification. See
    https://github.com/secure-systems-lab/dsse/blob/master/envelope.md
    for more details.

    Attributes:
        payload (grafeas.grafeas_v1.types.SbomReferenceIntotoPayload):
            The actual payload that contains the SBOM
            reference data.
        payload_type (str):
            The kind of payload that
            SbomReferenceIntotoPayload takes. Since it's in
            the intoto format, this value is expected to be
            'application/vnd.in-toto+json'.
        signatures (MutableSequence[grafeas.grafeas_v1.types.EnvelopeSignature]):
            The signatures over the payload.
    """

    payload: "SbomReferenceIntotoPayload" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="SbomReferenceIntotoPayload",
    )
    payload_type: str = proto.Field(
        proto.STRING,
        number=2,
    )
    signatures: MutableSequence[common.EnvelopeSignature] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=common.EnvelopeSignature,
    )


class SbomReferenceIntotoPayload(proto.Message):
    r"""The actual payload that contains the SBOM Reference data.
    The payload follows the intoto statement specification. See
    https://github.com/in-toto/attestation/blob/main/spec/v1.0/statement.md
    for more details.

    Attributes:
        type_ (str):
            Identifier for the schema of the Statement.
        predicate_type (str):
            URI identifying the type of the Predicate.
        subject (MutableSequence[grafeas.grafeas_v1.types.Subject]):
            Set of software artifacts that the
            attestation applies to. Each element represents
            a single software artifact.
        predicate (grafeas.grafeas_v1.types.SbomReferenceIntotoPredicate):
            Additional parameters of the Predicate.
            Includes the actual data about the SBOM.
    """

    type_: str = proto.Field(
        proto.STRING,
        number=1,
    )
    predicate_type: str = proto.Field(
        proto.STRING,
        number=2,
    )
    subject: MutableSequence[intoto_statement.Subject] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=intoto_statement.Subject,
    )
    predicate: "SbomReferenceIntotoPredicate" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="SbomReferenceIntotoPredicate",
    )


class SbomReferenceIntotoPredicate(proto.Message):
    r"""A predicate which describes the SBOM being referenced.

    Attributes:
        referrer_id (str):
            The person or system referring this predicate
            to the consumer.
        location (str):
            The location of the SBOM.
        mime_type (str):
            The mime type of the SBOM.
        digest (MutableMapping[str, str]):
            A map of algorithm to digest of the contents
            of the SBOM.
    """

    referrer_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    location: str = proto.Field(
        proto.STRING,
        number=2,
    )
    mime_type: str = proto.Field(
        proto.STRING,
        number=3,
    )
    digest: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "Severity",
    },
)


class Severity(proto.Enum):
    r"""Note provider assigned severity/impact ranking.

    Values:
        SEVERITY_UNSPECIFIED (0):
            Unknown.
        MINIMAL (1):
            Minimal severity.
        LOW (2):
            Low severity.
        MEDIUM (3):
            Medium severity.
        HIGH (4):
            High severity.
        CRITICAL (5):
            Critical severity.
    """
    SEVERITY_UNSPECIFIED = 0
    MINIMAL = 1
    LOW = 2
    MEDIUM = 3
    HIGH = 4
    CRITICAL = 5


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from grafeas.grafeas_v1.types import severity as g_severity

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "ComplianceNote",
        "ComplianceVersion",
        "ComplianceOccurrence",
        "NonCompliantFile",
    },
)


class ComplianceNote(proto.Message):
    r"""

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        title (str):
            The title that identifies this compliance
            check.
        description (str):
            A description about this compliance check.
        version (MutableSequence[grafeas.grafeas_v1.types.ComplianceVersion]):
            The OS and config versions the benchmark
            applies to.
        rationale (str):
            A rationale for the existence of this
            compliance check.
        remediation (str):
            A description of remediation steps if the
            compliance check fails.
        cis_benchmark (grafeas.grafeas_v1.types.ComplianceNote.CisBenchmark):

            This field is a member of `oneof`_ ``compliance_type``.
        scan_instructions (bytes):
            Serialized scan instructions with a
            predefined format.
        impact (str):

            This field is a member of `oneof`_ ``potential_impact``.
    """

    class CisBenchmark(proto.Message):
        r"""A compliance check that is a CIS benchmark.

        Attributes:
            profile_level (int):

            severity (grafeas.grafeas_v1.types.Severity):

        """

        profile_level: int = proto.Field(
            proto.INT32,
            number=1,
        )
        severity: g_severity.Severity = proto.Field(
            proto.ENUM,
            number=2,
            enum=g_severity.Severity,
        )

    title: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    version: MutableSequence["ComplianceVersion"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="ComplianceVersion",
    )
    rationale: str = proto.Field(
        proto.STRING,
        number=4,
    )
    remediation: str = proto.Field(
        proto.STRING,
        number=5,
    )
    cis_benchmark: CisBenchmark = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="compliance_type",
        message=CisBenchmark,
    )
    scan_instructions: bytes = proto.Field(
        proto.BYTES,
        number=7,
    )
    impact: str = proto.Field(
        proto.STRING,
        number=8,
        oneof="potential_impact",
    )


class ComplianceVersion(proto.Message):
    r"""Describes the CIS benchmark version that is applicable to a
    given OS and os version.

    Attributes:
        cpe_uri (str):
            The CPE URI
            (https://cpe.mitre.org/specification/) this
            benchmark is applicable to.
        benchmark_document (str):
            The name of the document that defines this
            benchmark, e.g. "CIS Container-Optimized OS".
        version (str):
            The version of the benchmark. This is set to
            the version of the OS-specific CIS document the
            benchmark is defined in.
    """

    cpe_uri: str = proto.Field(
        proto.STRING,
        number=1,
    )
    benchmark_document: str = proto.Field(
        proto.STRING,
        number=3,
    )
    version: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ComplianceOccurrence(proto.Message):
    r"""An indication that the compliance checks in the associated
    ComplianceNote were not satisfied for particular resources or a
    specified reason.

    Attributes:
        non_compliant_files (MutableSequence[grafeas.grafeas_v1.types.NonCompliantFile]):

        non_compliance_reason (str):

        version (grafeas.grafeas_v1.types.ComplianceVersion):
            The OS and config version the benchmark was
            run on.
    """

    non_compliant_files: MutableSequence["NonCompliantFile"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="NonCompliantFile",
    )
    non_compliance_reason: str = proto.Field(
        proto.STRING,
        number=3,
    )
    version: "ComplianceVersion" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="ComplianceVersion",
    )


class NonCompliantFile(proto.Message):
    r"""Details about files that caused a compliance check to fail.

    Attributes:
        path (str):
            Empty if ``display_command`` is set.
        display_command (str):
            Command to display the non-compliant files.
        reason (str):
            Explains why a file is non compliant for a
            CIS check.
    """

    path: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_command: str = proto.Field(
        proto.STRING,
        number=2,
    )
    reason: str = proto.Field(
        proto.STRING,
        number=3,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from grafeas.grafeas_v1.types import intoto_provenance as g_intoto_provenance
from grafeas.grafeas_v1.types import intoto_statement as g_intoto_statement
from grafeas.grafeas_v1.types import provenance as g_provenance

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "BuildNote",
        "BuildOccurrence",
    },
)


class BuildNote(proto.Message):
    r"""Note holding the version of the provider's builder and the
    signature of the provenance message in the build details
    occurrence.

    Attributes:
        builder_version (str):
            Required. Immutable. Version of the builder
            which produced this build.
    """

    builder_version: str = proto.Field(
        proto.STRING,
        number=1,
    )


class BuildOccurrence(proto.Message):
    r"""Details of a build occurrence.

    Attributes:
        provenance (grafeas.grafeas_v1.types.BuildProvenance):
            The actual provenance for the build.
        provenance_bytes (str):
            Serialized JSON representation of the provenance, used in
            generating the build signature in the corresponding build
            note. After verifying the signature, ``provenance_bytes``
            can be unmarshalled and compared to the provenance to
            confirm that it is unchanged. A base64-encoded string
            representation of the provenance bytes is used for the
            signature in order to interoperate with openssl which
            expects this format for signature verification.

            The serialized form is captured both to avoid ambiguity in
            how the provenance is marshalled to json as well to prevent
            incompatibilities with future changes.
        intoto_provenance (grafeas.grafeas_v1.types.InTotoProvenance):
            Deprecated. See InTotoStatement for the
            replacement. In-toto Provenance representation
            as defined in spec.
        intoto_statement (grafeas.grafeas_v1.types.InTotoStatement):
            In-toto Statement representation as defined in spec. The
            intoto_statement can contain any type of provenance. The
            serialized payload of the statement can be stored and signed
            in the Occurrence's envelope.
        in_toto_slsa_provenance_v1 (grafeas.grafeas_v1.types.InTotoSlsaProvenanceV1):
            In-Toto Slsa Provenance V1 represents a slsa
            provenance meeting the slsa spec, wrapped in an
            in-toto statement. This allows for direct
            jsonification of a to-spec in-toto slsa
            statement with a to-spec slsa provenance.
    """

    provenance: g_provenance.BuildProvenance = proto.Field(
        proto.MESSAGE,
        number=1,
        message=g_provenance.BuildProvenance,
    )
    provenance_bytes: str = proto.Field(
        proto.STRING,
        number=2,
    )
    intoto_provenance: g_intoto_provenance.InTotoProvenance = proto.Field(
        proto.MESSAGE,
        number=3,
        message=g_intoto_provenance.InTotoProvenance,
    )
    intoto_statement: g_intoto_statement.InTotoStatement = proto.Field(
        proto.MESSAGE,
        number=4,
        message=g_intoto_statement.InTotoStatement,
    )
    in_toto_slsa_provenance_v1: g_intoto_statement.InTotoSlsaProvenanceV1 = proto.Field(
        proto.MESSAGE,
        number=5,
        message=g_intoto_statement.InTotoSlsaProvenanceV1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from grafeas.grafeas_v1.types import common, cvss, package
from grafeas.grafeas_v1.types import severity as g_severity
from grafeas.grafeas_v1.types import vex

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "VulnerabilityNote",
        "VulnerabilityOccurrence",
    },
)


class VulnerabilityNote(proto.Message):
    r"""A security vulnerability that can be found in resources.

    Attributes:
        cvss_score (float):
            The CVSS score of this vulnerability. CVSS
            score is on a scale of 0 - 10 where 0 indicates
            low severity and 10 indicates high severity.
        severity (grafeas.grafeas_v1.types.Severity):
            The note provider assigned severity of this
            vulnerability.
        details (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityNote.Detail]):
            Details of all known distros and packages
            affected by this vulnerability.
        cvss_v3 (grafeas.grafeas_v1.types.CVSSv3):
            The full description of the CVSSv3 for this
            vulnerability.
        windows_details (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityNote.WindowsDetail]):
            Windows details get their own format because
            the information format and model don't match a
            normal detail. Specifically Windows updates are
            done as patches, thus Windows vulnerabilities
            really are a missing package, rather than a
            package being at an incorrect version.
        source_update_time (google.protobuf.timestamp_pb2.Timestamp):
            The time this information was last changed at
            the source. This is an upstream timestamp from
            the underlying information source - e.g. Ubuntu
            security tracker.
        cvss_version (grafeas.grafeas_v1.types.CVSSVersion):
            CVSS version used to populate cvss_score and severity.
        cvss_v2 (grafeas.grafeas_v1.types.CVSS):
            The full description of the v2 CVSS for this
            vulnerability.
    """

    class Detail(proto.Message):
        r"""A detail for a distro and package affected by this
        vulnerability and its associated fix (if one is available).

        Attributes:
            severity_name (str):
                The distro assigned severity of this
                vulnerability.
            description (str):
                A vendor-specific description of this
                vulnerability.
            package_type (str):
                The type of package; whether native or non
                native (e.g., ruby gems, node.js packages,
                etc.).
            affected_cpe_uri (str):
                Required. The `CPE
                URI <https://cpe.mitre.org/specification/>`__ this
                vulnerability affects.
            affected_package (str):
                Required. The package this vulnerability
                affects.
            affected_version_start (grafeas.grafeas_v1.types.Version):
                The version number at the start of an interval in which this
                vulnerability exists. A vulnerability can affect a package
                between version numbers that are disjoint sets of intervals
                (example: [1.0.0-1.1.0], [2.4.6-2.4.8] and [4.5.6-4.6.8])
                each of which will be represented in its own Detail. If a
                specific affected version is provided by a vulnerability
                database, affected_version_start and affected_version_end
                will be the same in that Detail.
            affected_version_end (grafeas.grafeas_v1.types.Version):
                The version number at the end of an interval in which this
                vulnerability exists. A vulnerability can affect a package
                between version numbers that are disjoint sets of intervals
                (example: [1.0.0-1.1.0], [2.4.6-2.4.8] and [4.5.6-4.6.8])
                each of which will be represented in its own Detail. If a
                specific affected version is provided by a vulnerability
                database, affected_version_start and affected_version_end
                will be the same in that Detail.
            fixed_cpe_uri (str):
                The distro recommended `CPE
                URI <https://cpe.mitre.org/specification/>`__ to update to
                that contains a fix for this vulnerability. It is possible
                for this to be different from the affected_cpe_uri.
            fixed_package (str):
                The distro recommended package to update to that contains a
                fix for this vulnerability. It is possible for this to be
                different from the affected_package.
            fixed_version (grafeas.grafeas_v1.types.Version):
                The distro recommended version to update to
                that contains a fix for this vulnerability.
                Setting this to VersionKind.MAXIMUM means no
                such version is yet available.
            is_obsolete (bool):
                Whether this detail is obsolete. Occurrences
                are expected not to point to obsolete details.
            source_update_time (google.protobuf.timestamp_pb2.Timestamp):
                The time this information was last changed at
                the source. This is an upstream timestamp from
                the underlying information source - e.g. Ubuntu
                security tracker.
            source (str):
                The source from which the information in this
                Detail was obtained.
            vendor (str):
                The name of the vendor of the product.
        """

        severity_name: str = proto.Field(
            proto.STRING,
            number=1,
        )
        description: str = proto.Field(
            proto.STRING,
            number=2,
        )
        package_type: str = proto.Field(
            proto.STRING,
            number=3,
        )
        affected_cpe_uri: str = proto.Field(
            proto.STRING,
            number=4,
        )
        affected_package: str = proto.Field(
            proto.STRING,
            number=5,
        )
        affected_version_start: package.Version = proto.Field(
            proto.MESSAGE,
            number=6,
            message=package.Version,
        )
        affected_version_end: package.Version = proto.Field(
            proto.MESSAGE,
            number=7,
            message=package.Version,
        )
        fixed_cpe_uri: str = proto.Field(
            proto.STRING,
            number=8,
        )
        fixed_package: str = proto.Field(
            proto.STRING,
            number=9,
        )
        fixed_version: package.Version = proto.Field(
            proto.MESSAGE,
            number=10,
            message=package.Version,
        )
        is_obsolete: bool = proto.Field(
            proto.BOOL,
            number=11,
        )
        source_update_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=12,
            message=timestamp_pb2.Timestamp,
        )
        source: str = proto.Field(
            proto.STRING,
            number=13,
        )
        vendor: str = proto.Field(
            proto.STRING,
            number=14,
        )

    class WindowsDetail(proto.Message):
        r"""

        Attributes:
            cpe_uri (str):
                Required. The `CPE
                URI <https://cpe.mitre.org/specification/>`__ this
                vulnerability affects.
            name (str):
                Required. The name of this vulnerability.
            description (str):
                The description of this vulnerability.
            fixing_kbs (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityNote.WindowsDetail.KnowledgeBase]):
                Required. The names of the KBs which have
                hotfixes to mitigate this vulnerability. Note
                that there may be multiple hotfixes (and thus
                multiple KBs) that mitigate a given
                vulnerability. Currently any listed KBs presence
                is considered a fix.
        """

        class KnowledgeBase(proto.Message):
            r"""

            Attributes:
                name (str):
                    The KB name (generally of the form KB[0-9]+ (e.g.,
                    KB123456)).
                url (str):
                    A link to the KB in the [Windows update catalog]
                    (https://www.catalog.update.microsoft.com/).
            """

            name: str = proto.Field(
                proto.STRING,
                number=1,
            )
            url: str = proto.Field(
                proto.STRING,
                number=2,
            )

        cpe_uri: str = proto.Field(
            proto.STRING,
            number=1,
        )
        name: str = proto.Field(
            proto.STRING,
            number=2,
        )
        description: str = proto.Field(
            proto.STRING,
            number=3,
        )
        fixing_kbs: MutableSequence[
            "VulnerabilityNote.WindowsDetail.KnowledgeBase"
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=4,
            message="VulnerabilityNote.WindowsDetail.KnowledgeBase",
        )

    cvss_score: float = proto.Field(
        proto.FLOAT,
        number=1,
    )
    severity: g_severity.Severity = proto.Field(
        proto.ENUM,
        number=2,
        enum=g_severity.Severity,
    )
    details: MutableSequence[Detail] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=Detail,
    )
    cvss_v3: cvss.CVSSv3 = proto.Field(
        proto.MESSAGE,
        number=4,
        message=cvss.CVSSv3,
    )
    windows_details: MutableSequence[WindowsDetail] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=WindowsDetail,
    )
    source_update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    cvss_version: cvss.CVSSVersion = proto.Field(
        proto.ENUM,
        number=7,
        enum=cvss.CVSSVersion,
    )
    cvss_v2: cvss.CVSS = proto.Field(
        proto.MESSAGE,
        number=8,
        message=cvss.CVSS,
    )


class VulnerabilityOccurrence(proto.Message):
    r"""An occurrence of a severity vulnerability on a resource.

    Attributes:
        type_ (str):
            The type of package; whether native or non
            native (e.g., ruby gems, node.js packages,
            etc.).
        severity (grafeas.grafeas_v1.types.Severity):
            Output only. The note provider assigned
            severity of this vulnerability.
        cvss_score (float):
            Output only. The CVSS score of this
            vulnerability. CVSS score is on a scale of 0 -
            10 where 0 indicates low severity and 10
            indicates high severity.
        cvssv3 (grafeas.grafeas_v1.types.CVSS):
            The cvss v3 score for the vulnerability.
        package_issue (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityOccurrence.PackageIssue]):
            Required. The set of affected locations and
            their fixes (if available) within the associated
            resource.
        short_description (str):
            Output only. A one sentence description of
            this vulnerability.
        long_description (str):
            Output only. A detailed description of this
            vulnerability.
        related_urls (MutableSequence[grafeas.grafeas_v1.types.RelatedUrl]):
            Output only. URLs related to this
            vulnerability.
        effective_severity (grafeas.grafeas_v1.types.Severity):
            The distro assigned severity for this
            vulnerability when it is available, otherwise
            this is the note provider assigned severity.

            When there are multiple PackageIssues for this
            vulnerability, they can have different effective
            severities because some might be provided by the
            distro while others are provided by the language
            ecosystem for a language pack. For this reason,
            it is advised to use the effective severity on
            the PackageIssue level. In the case where
            multiple PackageIssues have differing effective
            severities, this field should be the highest
            severity for any of the PackageIssues.
        fix_available (bool):
            Output only. Whether at least one of the
            affected packages has a fix available.
        cvss_version (grafeas.grafeas_v1.types.CVSSVersion):
            Output only. CVSS version used to populate cvss_score and
            severity.
        cvss_v2 (grafeas.grafeas_v1.types.CVSS):
            The cvss v2 score for the vulnerability.
        vex_assessment (grafeas.grafeas_v1.types.VulnerabilityOccurrence.VexAssessment):

        extra_details (str):
            Occurrence-specific extra details about the
            vulnerability.
    """

    class PackageIssue(proto.Message):
        r"""A detail for a distro and package this vulnerability
        occurrence was found in and its associated fix (if one is
        available).

        Attributes:
            affected_cpe_uri (str):
                Required. The `CPE
                URI <https://cpe.mitre.org/specification/>`__ this
                vulnerability was found in.
            affected_package (str):
                Required. The package this vulnerability was
                found in.
            affected_version (grafeas.grafeas_v1.types.Version):
                Required. The version of the package that is
                installed on the resource affected by this
                vulnerability.
            fixed_cpe_uri (str):
                The `CPE URI <https://cpe.mitre.org/specification/>`__ this
                vulnerability was fixed in. It is possible for this to be
                different from the affected_cpe_uri.
            fixed_package (str):
                The package this vulnerability was fixed in. It is possible
                for this to be different from the affected_package.
            fixed_version (grafeas.grafeas_v1.types.Version):
                Required. The version of the package this
                vulnerability was fixed in. Setting this to
                VersionKind.MAXIMUM means no fix is yet
                available.
            fix_available (bool):
                Output only. Whether a fix is available for
                this package.
            package_type (str):
                The type of package (e.g. OS, MAVEN, GO).
            effective_severity (grafeas.grafeas_v1.types.Severity):
                The distro or language system assigned
                severity for this vulnerability when that is
                available and note provider assigned severity
                when it is not available.
            file_location (MutableSequence[grafeas.grafeas_v1.types.FileLocation]):
                The location at which this package was found.
        """

        affected_cpe_uri: str = proto.Field(
            proto.STRING,
            number=1,
        )
        affected_package: str = proto.Field(
            proto.STRING,
            number=2,
        )
        affected_version: package.Version = proto.Field(
            proto.MESSAGE,
            number=3,
            message=package.Version,
        )
        fixed_cpe_uri: str = proto.Field(
            proto.STRING,
            number=4,
        )
        fixed_package: str = proto.Field(
            proto.STRING,
            number=5,
        )
        fixed_version: package.Version = proto.Field(
            proto.MESSAGE,
            number=6,
            message=package.Version,
        )
        fix_available: bool = proto.Field(
            proto.BOOL,
            number=7,
        )
        package_type: str = proto.Field(
            proto.STRING,
            number=8,
        )
        effective_severity: g_severity.Severity = proto.Field(
            proto.ENUM,
            number=9,
            enum=g_severity.Severity,
        )
        file_location: MutableSequence[common.FileLocation] = proto.RepeatedField(
            proto.MESSAGE,
            number=10,
            message=common.FileLocation,
        )

    class VexAssessment(proto.Message):
        r"""VexAssessment provides all publisher provided Vex information
        that is related to this vulnerability.

        Attributes:
            cve (str):
                Holds the MITRE standard Common Vulnerabilities and
                Exposures (CVE) tracking number for the vulnerability.
                Deprecated: Use vulnerability_id instead to denote CVEs.
            vulnerability_id (str):
                The vulnerability identifier for this
                Assessment. Will hold one of common identifiers
                e.g. CVE, GHSA etc.
            related_uris (MutableSequence[grafeas.grafeas_v1.types.RelatedUrl]):
                Holds a list of references associated with
                this vulnerability item and assessment.
            note_name (str):
                The VulnerabilityAssessment note from which this
                VexAssessment was generated. This will be of the form:
                ``projects/[PROJECT_ID]/notes/[NOTE_ID]``. (-- api-linter:
                core::0122::name-suffix=disabled aip.dev/not-precedent: The
                suffix is kept for consistency. --)
            state (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Assessment.State):
                Provides the state of this Vulnerability
                assessment.
            impacts (MutableSequence[str]):
                Contains information about the impact of this
                vulnerability, this will change with time.
            remediations (MutableSequence[grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Assessment.Remediation]):
                Specifies details on how to handle (and
                presumably, fix) a vulnerability.
            justification (grafeas.grafeas_v1.types.VulnerabilityAssessmentNote.Assessment.Justification):
                Justification provides the justification when the state of
                the assessment if NOT_AFFECTED.
        """

        cve: str = proto.Field(
            proto.STRING,
            number=1,
        )
        vulnerability_id: str = proto.Field(
            proto.STRING,
            number=8,
        )
        related_uris: MutableSequence[common.RelatedUrl] = proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message=common.RelatedUrl,
        )
        note_name: str = proto.Field(
            proto.STRING,
            number=3,
        )
        state: vex.VulnerabilityAssessmentNote.Assessment.State = proto.Field(
            proto.ENUM,
            number=4,
            enum=vex.VulnerabilityAssessmentNote.Assessment.State,
        )
        impacts: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=5,
        )
        remediations: MutableSequence[
            vex.VulnerabilityAssessmentNote.Assessment.Remediation
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=6,
            message=vex.VulnerabilityAssessmentNote.Assessment.Remediation,
        )
        justification: vex.VulnerabilityAssessmentNote.Assessment.Justification = (
            proto.Field(
                proto.MESSAGE,
                number=7,
                message=vex.VulnerabilityAssessmentNote.Assessment.Justification,
            )
        )

    type_: str = proto.Field(
        proto.STRING,
        number=1,
    )
    severity: g_severity.Severity = proto.Field(
        proto.ENUM,
        number=2,
        enum=g_severity.Severity,
    )
    cvss_score: float = proto.Field(
        proto.FLOAT,
        number=3,
    )
    cvssv3: cvss.CVSS = proto.Field(
        proto.MESSAGE,
        number=10,
        message=cvss.CVSS,
    )
    package_issue: MutableSequence[PackageIssue] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=PackageIssue,
    )
    short_description: str = proto.Field(
        proto.STRING,
        number=5,
    )
    long_description: str = proto.Field(
        proto.STRING,
        number=6,
    )
    related_urls: MutableSequence[common.RelatedUrl] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message=common.RelatedUrl,
    )
    effective_severity: g_severity.Severity = proto.Field(
        proto.ENUM,
        number=8,
        enum=g_severity.Severity,
    )
    fix_available: bool = proto.Field(
        proto.BOOL,
        number=9,
    )
    cvss_version: cvss.CVSSVersion = proto.Field(
        proto.ENUM,
        number=11,
        enum=cvss.CVSSVersion,
    )
    cvss_v2: cvss.CVSS = proto.Field(
        proto.MESSAGE,
        number=12,
        message=cvss.CVSS,
    )
    vex_assessment: VexAssessment = proto.Field(
        proto.MESSAGE,
        number=13,
        message=VexAssessment,
    )
    extra_details: str = proto.Field(
        proto.STRING,
        number=14,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from grafeas.grafeas_v1.types import common

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "Architecture",
        "Distribution",
        "Location",
        "PackageNote",
        "PackageOccurrence",
        "Version",
    },
)


class Architecture(proto.Enum):
    r"""Instruction set architectures supported by various package
    managers.

    Values:
        ARCHITECTURE_UNSPECIFIED (0):
            Unknown architecture.
        X86 (1):
            X86 architecture.
        X64 (2):
            X64 architecture.
    """
    ARCHITECTURE_UNSPECIFIED = 0
    X86 = 1
    X64 = 2


class Distribution(proto.Message):
    r"""This represents a particular channel of distribution for a
    given package. E.g., Debian's jessie-backports dpkg mirror.

    Attributes:
        cpe_uri (str):
            The cpe_uri in `CPE
            format <https://cpe.mitre.org/specification/>`__ denoting
            the package manager version distributing a package.
        architecture (grafeas.grafeas_v1.types.Architecture):
            The CPU architecture for which packages in
            this distribution channel were built.
        latest_version (grafeas.grafeas_v1.types.Version):
            The latest available version of this package
            in this distribution channel.
        maintainer (str):
            A freeform string denoting the maintainer of
            this package.
        url (str):
            The distribution channel-specific homepage
            for this package.
        description (str):
            The distribution channel-specific description
            of this package.
    """

    cpe_uri: str = proto.Field(
        proto.STRING,
        number=1,
    )
    architecture: "Architecture" = proto.Field(
        proto.ENUM,
        number=2,
        enum="Architecture",
    )
    latest_version: "Version" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="Version",
    )
    maintainer: str = proto.Field(
        proto.STRING,
        number=4,
    )
    url: str = proto.Field(
        proto.STRING,
        number=5,
    )
    description: str = proto.Field(
        proto.STRING,
        number=6,
    )


class Location(proto.Message):
    r"""An occurrence of a particular package installation found within a
    system's filesystem. E.g., glibc was found in
    ``/var/lib/dpkg/status``.

    Attributes:
        cpe_uri (str):
            Deprecated. The CPE URI in `CPE
            format <https://cpe.mitre.org/specification/>`__
        version (grafeas.grafeas_v1.types.Version):
            Deprecated.
            The version installed at this location.
        path (str):
            The path from which we gathered that this
            package/version is installed.
    """

    cpe_uri: str = proto.Field(
        proto.STRING,
        number=1,
    )
    version: "Version" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Version",
    )
    path: str = proto.Field(
        proto.STRING,
        number=3,
    )


class PackageNote(proto.Message):
    r"""PackageNote represents a particular package version.

    Attributes:
        name (str):
            The name of the package.
        distribution (MutableSequence[grafeas.grafeas_v1.types.Distribution]):
            Deprecated.
            The various channels by which a package is
            distributed.
        package_type (str):
            The type of package; whether native or non
            native (e.g., ruby gems, node.js packages,
            etc.).
        cpe_uri (str):
            The cpe_uri in `CPE
            format <https://cpe.mitre.org/specification/>`__ denoting
            the package manager version distributing a package. The
            cpe_uri will be blank for language packages.
        architecture (grafeas.grafeas_v1.types.Architecture):
            The CPU architecture for which packages in
            this distribution channel were built.
            Architecture will be blank for language
            packages.
        version (grafeas.grafeas_v1.types.Version):
            The version of the package.
        maintainer (str):
            A freeform text denoting the maintainer of
            this package.
        url (str):
            The homepage for this package.
        description (str):
            The description of this package.
        license_ (grafeas.grafeas_v1.types.License):
            Licenses that have been declared by the
            authors of the package.
        digest (MutableSequence[grafeas.grafeas_v1.types.Digest]):
            Hash value, typically a file digest, that
            allows unique identification a specific package.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    distribution: MutableSequence["Distribution"] = proto.RepeatedField(
        proto.MESSAGE,
        number=10,
        message="Distribution",
    )
    package_type: str = proto.Field(
        proto.STRING,
        number=11,
    )
    cpe_uri: str = proto.Field(
        proto.STRING,
        number=12,
    )
    architecture: "Architecture" = proto.Field(
        proto.ENUM,
        number=13,
        enum="Architecture",
    )
    version: "Version" = proto.Field(
        proto.MESSAGE,
        number=14,
        message="Version",
    )
    maintainer: str = proto.Field(
        proto.STRING,
        number=15,
    )
    url: str = proto.Field(
        proto.STRING,
        number=16,
    )
    description: str = proto.Field(
        proto.STRING,
        number=17,
    )
    license_: common.License = proto.Field(
        proto.MESSAGE,
        number=18,
        message=common.License,
    )
    digest: MutableSequence[common.Digest] = proto.RepeatedField(
        proto.MESSAGE,
        number=19,
        message=common.Digest,
    )


class PackageOccurrence(proto.Message):
    r"""Details on how a particular software package was installed on
    a system.

    Attributes:
        name (str):
            The name of the installed package.
        location (MutableSequence[grafeas.grafeas_v1.types.Location]):
            All of the places within the filesystem
            versions of this package have been found.
        package_type (str):
            The type of package; whether native or non
            native (e.g., ruby gems, node.js packages,
            etc.).
        cpe_uri (str):
            The cpe_uri in `CPE
            format <https://cpe.mitre.org/specification/>`__ denoting
            the package manager version distributing a package. The
            cpe_uri will be blank for language packages.
        architecture (grafeas.grafeas_v1.types.Architecture):
            The CPU architecture for which packages in
            this distribution channel were built.
            Architecture will be blank for language
            packages.
        license_ (grafeas.grafeas_v1.types.License):
            Licenses that have been declared by the
            authors of the package.
        version (grafeas.grafeas_v1.types.Version):
            The version of the package.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    location: MutableSequence["Location"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="Location",
    )
    package_type: str = proto.Field(
        proto.STRING,
        number=3,
    )
    cpe_uri: str = proto.Field(
        proto.STRING,
        number=4,
    )
    architecture: "Architecture" = proto.Field(
        proto.ENUM,
        number=5,
        enum="Architecture",
    )
    license_: common.License = proto.Field(
        proto.MESSAGE,
        number=6,
        message=common.License,
    )
    version: "Version" = proto.Field(
        proto.MESSAGE,
        number=7,
        message="Version",
    )


class Version(proto.Message):
    r"""Version contains structured information about the version of
    a package.

    Attributes:
        epoch (int):
            Used to correct mistakes in the version
            numbering scheme.
        name (str):
            Required only when version kind is NORMAL.
            The main part of the version name.
        revision (str):
            The iteration of the package build from the
            above version.
        inclusive (bool):
            Whether this version is specifying part of an
            inclusive range. Grafeas does not have the
            capability to specify version ranges; instead we
            have fields that specify start version and end
            versions. At times this is insufficient - we
            also need to specify whether the version is
            included in the range or is excluded from the
            range. This boolean is expected to be set to
            true when the version is included in a range.
        kind (grafeas.grafeas_v1.types.Version.VersionKind):
            Required. Distinguishes between sentinel
            MIN/MAX versions and normal versions.
        full_name (str):
            Human readable version string. This string is
            of the form <epoch>:<name>-<revision> and is
            only set when kind is NORMAL.
    """

    class VersionKind(proto.Enum):
        r"""Whether this is an ordinary package version or a sentinel
        MIN/MAX version.

        Values:
            VERSION_KIND_UNSPECIFIED (0):
                Unknown.
            NORMAL (1):
                A standard package version.
            MINIMUM (2):
                A special version representing negative
                infinity.
            MAXIMUM (3):
                A special version representing positive
                infinity.
        """
        VERSION_KIND_UNSPECIFIED = 0
        NORMAL = 1
        MINIMUM = 2
        MAXIMUM = 3

    epoch: int = proto.Field(
        proto.INT32,
        number=1,
    )
    name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    revision: str = proto.Field(
        proto.STRING,
        number=3,
    )
    inclusive: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    kind: VersionKind = proto.Field(
        proto.ENUM,
        number=4,
        enum=VersionKind,
    )
    full_name: str = proto.Field(
        proto.STRING,
        number=5,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from grafeas.grafeas_v1.types import common

__protobuf__ = proto.module(
    package="grafeas.v1",
    manifest={
        "AttestationNote",
        "Jwt",
        "AttestationOccurrence",
    },
)


class AttestationNote(proto.Message):
    r"""Note kind that represents a logical attestation "role" or
    "authority". For example, an organization might have one
    ``Authority`` for "QA" and one for "build". This note is intended to
    act strictly as a grouping mechanism for the attached occurrences
    (Attestations). This grouping mechanism also provides a security
    boundary, since IAM ACLs gate the ability for a principle to attach
    an occurrence to a given note. It also provides a single point of
    lookup to find all attached attestation occurrences, even if they
    don't all live in the same project.

    Attributes:
        hint (grafeas.grafeas_v1.types.AttestationNote.Hint):
            Hint hints at the purpose of the attestation
            authority.
    """

    class Hint(proto.Message):
        r"""This submessage provides human-readable hints about the
        purpose of the authority. Because the name of a note acts as its
        resource reference, it is important to disambiguate the
        canonical name of the Note (which might be a UUID for security
        purposes) from "readable" names more suitable for debug output.
        Note that these hints should not be used to look up authorities
        in security sensitive contexts, such as when looking up
        attestations to verify.

        Attributes:
            human_readable_name (str):
                Required. The human readable name of this
                attestation authority, for example "qa".
        """

        human_readable_name: str = proto.Field(
            proto.STRING,
            number=1,
        )

    hint: Hint = proto.Field(
        proto.MESSAGE,
        number=1,
        message=Hint,
    )


class Jwt(proto.Message):
    r"""

    Attributes:
        compact_jwt (str):
            The compact encoding of a JWS, which is
            always three base64 encoded strings joined by
            periods. For details, see:

            https://tools.ietf.org/html/rfc7515.html#section-3.1
    """

    compact_jwt: str = proto.Field(
        proto.STRING,
        number=1,
    )


class AttestationOccurrence(proto.Message):
    r"""Occurrence that represents a single "attestation". The
    authenticity of an attestation can be verified using the
    attached signature. If the verifier trusts the public key of the
    signer, then verifying the signature is sufficient to establish
    trust. In this circumstance, the authority to which this
    attestation is attached is primarily useful for lookup (how to
    find this attestation if you already know the authority and
    artifact to be verified) and intent (for which authority this
    attestation was intended to sign.

    Attributes:
        serialized_payload (bytes):
            Required. The serialized payload that is verified by one or
            more ``signatures``.
        signatures (MutableSequence[grafeas.grafeas_v1.types.Signature]):
            One or more signatures over ``serialized_payload``. Verifier
            implementations should consider this attestation message
            verified if at least one ``signature`` verifies
            ``serialized_payload``. See ``Signature`` in common.proto
            for more details on signature structure and verification.
        jwts (MutableSequence[grafeas.grafeas_v1.types.Jwt]):
            One or more JWTs encoding a self-contained attestation. Each
            JWT encodes the payload that it verifies within the JWT
            itself. Verifier implementation SHOULD ignore the
            ``serialized_payload`` field when verifying these JWTs. If
            only JWTs are present on this AttestationOccurrence, then
            the ``serialized_payload`` SHOULD be left empty. Each JWT
            SHOULD encode a claim specific to the ``resource_uri`` of
            this Occurrence, but this is not validated by Grafeas
            metadata API implementations. The JWT itself is opaque to
            Grafeas.
    """

    serialized_payload: bytes = proto.Field(
        proto.BYTES,
        number=1,
    )
    signatures: MutableSequence[common.Signature] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=common.Signature,
    )
    jwts: MutableSequence["Jwt"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="Jwt",
    )


__all__ = tuple(sorted(__protobuf__.manifest))
